@@ -57,7 +57,7 @@
 
 /** \brief JSON (JavaScript Object Notation).
  */
-namespace Json {
+namespace AliasJson { 
 
 #if JSON_USE_EXCEPTION
 /** Base class for all exceptions we throw.
@@ -78,7 +78,7 @@ protected:
  *
  * E.g. out-of-memory (when we use malloc), stack-overflow, malicious input
  *
- * \remark derived from Json::Exception
+ * \remark derived from AliasJson::Exception
  */
 class JSON_API RuntimeError : public Exception {
 public:
@@ -89,7 +89,7 @@ public:
  *
  * These are precondition-violations (user bugs) and internal errors (our bugs).
  *
- * \remark derived from Json::Exception
+ * \remark derived from AliasJson::Exception
  */
 class JSON_API LogicError : public Exception {
 public:
@@ -138,8 +138,8 @@ enum PrecisionType {
  *
  * Example of usage:
  * \code
- * Json::Value aValue( StaticString("some text") );
- * Json::Value object;
+ * AliasJson::Value aValue( StaticString("some text") );
+ * AliasJson::Value object;
  * static const StaticString code("code");
  * object[code] = 1234;
  * \endcode
@@ -197,15 +197,15 @@ public:
   using Members = std::vector<String>;
   using iterator = ValueIterator;
   using const_iterator = ValueConstIterator;
-  using UInt = Json::UInt;
-  using Int = Json::Int;
+  using UInt = AliasJson::UInt;
+  using Int = AliasJson::Int;
 #if defined(JSON_HAS_INT64)
-  using UInt64 = Json::UInt64;
-  using Int64 = Json::Int64;
+  using UInt64 = AliasJson::UInt64;
+  using Int64 = AliasJson::Int64;
 #endif // defined(JSON_HAS_INT64)
-  using LargestInt = Json::LargestInt;
-  using LargestUInt = Json::LargestUInt;
-  using ArrayIndex = Json::ArrayIndex;
+  using LargestInt = AliasJson::LargestInt;
+  using LargestUInt = AliasJson::LargestUInt;
+  using ArrayIndex = AliasJson::ArrayIndex;
 
   // Required for boost integration, e. g. BOOST_TEST
   using value_type = std::string;
@@ -219,27 +219,27 @@ public:
   // null and nullRef are deprecated, use this instead.
   static Value const& nullSingleton();
 
-  /// Minimum signed integer value that can be stored in a Json::Value.
+  /// Minimum signed integer value that can be stored in a AliasJson::Value.
   static constexpr LargestInt minLargestInt =
       LargestInt(~(LargestUInt(-1) / 2));
-  /// Maximum signed integer value that can be stored in a Json::Value.
+  /// Maximum signed integer value that can be stored in a AliasJson::Value.
   static constexpr LargestInt maxLargestInt = LargestInt(LargestUInt(-1) / 2);
-  /// Maximum unsigned integer value that can be stored in a Json::Value.
+  /// Maximum unsigned integer value that can be stored in a AliasJson::Value.
   static constexpr LargestUInt maxLargestUInt = LargestUInt(-1);
 
-  /// Minimum signed int value that can be stored in a Json::Value.
+  /// Minimum signed int value that can be stored in a AliasJson::Value.
   static constexpr Int minInt = Int(~(UInt(-1) / 2));
-  /// Maximum signed int value that can be stored in a Json::Value.
+  /// Maximum signed int value that can be stored in a AliasJson::Value.
   static constexpr Int maxInt = Int(UInt(-1) / 2);
-  /// Maximum unsigned int value that can be stored in a Json::Value.
+  /// Maximum unsigned int value that can be stored in a AliasJson::Value.
   static constexpr UInt maxUInt = UInt(-1);
 
 #if defined(JSON_HAS_INT64)
-  /// Minimum signed 64 bits int value that can be stored in a Json::Value.
+  /// Minimum signed 64 bits int value that can be stored in a AliasJson::Value.
   static constexpr Int64 minInt64 = Int64(~(UInt64(-1) / 2));
-  /// Maximum signed 64 bits int value that can be stored in a Json::Value.
+  /// Maximum signed 64 bits int value that can be stored in a AliasJson::Value.
   static constexpr Int64 maxInt64 = Int64(UInt64(-1) / 2);
-  /// Maximum unsigned 64 bits int value that can be stored in a Json::Value.
+  /// Maximum unsigned 64 bits int value that can be stored in a AliasJson::Value.
   static constexpr UInt64 maxUInt64 = UInt64(-1);
 #endif // defined(JSON_HAS_INT64)
   /// Default precision for real value for string representation.
@@ -307,9 +307,9 @@ public:
    *
    * Examples:
    *   \code
-   *   Json::Value null_value; // null
-   *   Json::Value arr_value(Json::arrayValue); // []
-   *   Json::Value obj_value(Json::objectValue); // {}
+   *   AliasJson::Value null_value; // null
+   *   AliasJson::Value arr_value(AliasJson::arrayValue); // []
+   *   AliasJson::Value obj_value(AliasJson::objectValue); // {}
    *   \endcode
    */
   Value(ValueType type = nullValue);
@@ -336,7 +336,7 @@ public:
    * Example of usage:
    *   \code
    *   static StaticString foo("some text");
-   *   Json::Value aValue(foo);
+   *   AliasJson::Value aValue(foo);
    *   \endcode
    */
   Value(const StaticString& value);
@@ -490,7 +490,7 @@ public:
    * store the new entry is not duplicated.
    * Example of use:
    *   \code
-   *   Json::Value object;
+   *   AliasJson::Value object;
    *   static const StaticString code("code");
    *   object[code] = 1234;
    *   \endcode
@@ -924,7 +924,7 @@ public:
 
 inline void swap(Value& a, Value& b) { a.swap(b); }
 
-} // namespace Json
+} // namespace AliasJson
 
 #pragma pack(pop)
 
