@@ -2,30 +2,30 @@
 import unittest
 from multiprocessing import Process
 import time
-import pinpointPy
+import _pinpointPy
 import random
 
 class TestUnderProcessMode(TestCase):
 
     def tearDown(self):
-        pinpointPy.force_flush_trace(4)
+        _pinpointPy.force_flush_trace(4)
 
     def _test_api_flow(self):
-        self.assertTrue(pinpointPy.set_agent(collector_host='unix:/tmp/unexist.sock'))
-        # self.assertTrue(pinpointPy.enable_debug(None))
+        self.assertTrue(_pinpointPy.set_agent(collector_host='unix:/tmp/unexist.sock'))
+        # self.assertTrue(_pinpointPy.enable_debug(None))
 
         while True:
             id = str(random.randint(1,10000000))
-            pinpointPy.start_trace()
-            pinpointPy.set_context_key('sid',id)
-            pinpointPy.add_clue("key","value3")
-            pinpointPy.add_clues("key","value3")
-            value = pinpointPy.get_context_key('sid')
+            _pinpointPy.start_trace()
+            _pinpointPy.set_context_key('sid',id)
+            _pinpointPy.add_clue("key","value3")
+            _pinpointPy.add_clues("key","value3")
+            value = _pinpointPy.get_context_key('sid')
             self.assertEqual(value,id)
-            pinpointPy.mark_as_error("fghjk","fghjkl",234234)
-            pinpointPy.end_trace()
-            pinpointPy.force_flush_trace()
-            pinpointPy.drop_trace()
+            _pinpointPy.mark_as_error("fghjk","fghjkl",234234)
+            _pinpointPy.end_trace()
+            _pinpointPy.force_flush_trace()
+            _pinpointPy.drop_trace()
 
     def test_process(self):
         p1 = Process(target=self._test_api_flow)
